@@ -1,6 +1,6 @@
-pub fn strip_dag(vertex: &str, vertice_to_strip: &str) -> String {
-    let dag = vertex.split(",").collect::<Vec<&str>>();
-    let dag_original_length = dag.len();
+pub fn strip_dag(original_dag: &str, vertice_to_strip: &str) -> String {
+    let dag = original_dag.split(",").collect::<Vec<&str>>();
+    let original_dag_len = dag.len();
 
     // Allocating the patterns to strip given a character
     let strip_pattern_1 = format!("-{}", vertice_to_strip);
@@ -8,10 +8,10 @@ pub fn strip_dag(vertex: &str, vertice_to_strip: &str) -> String {
     let strip_pattern_3 = format!("{}", vertice_to_strip);
 
     // Allocating a mutable vec to create the newly formatted dag. We know the length won't exceed the original's
-    let mut new_dag: Vec<String> = Vec::with_capacity(dag_original_length);
+    let mut new_dag: Vec<String> = Vec::with_capacity(original_dag_len);
 
     // Keeping track of the indexes we've connected branches from to avoid unnecessary iterations. We know the length won't exceed the original's
-    let mut idx_to_skip: Vec<usize> = Vec::with_capacity(dag_original_length);
+    let mut idx_to_skip: Vec<usize> = Vec::with_capacity(original_dag_len);
 
     // The index that will allow us to look ahead from an interation to know if we're able to create a branch from a single vertice
     let mut next_idx: usize;
